@@ -1,5 +1,5 @@
 mod queries;
 mod mungos;
 mod collection;
-pub use mongodb::{options::FindOptions, bson::doc};
+pub use mongodb::{options::FindOptions, bson::{doc, oid::ObjectId}};
 pub use crate::{mungos::Mungos, collection::Collection};
\ No newline at end of file
